<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://demetrachat.com.br
 * @since      1.0.0
 *
 * @package    Demetrachat
 * @subpackage Demetrachat/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Demetrachat
 * @subpackage Demetrachat/public
 * @author     Demetra Chat <contact@demetrachat.com.br>
 */
class Demetrachat_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
    $this->version = $version;

    $this->demetrachat_options = get_option($this->plugin_name);
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Demetrachat_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Demetrachat_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/demetrachat-public.css', array(), $this->version, 'all' );

	}

  /**
   * Register the JavaScript for the public-facing side of the site.
   *
   * @since    1.0.0
  */
  public function enqueue_scripts() {
    if (empty($this->demetrachat_options['id'])) return;
    $APP_URL = 'https://app.demetrachat.com.br/';
    ?>
    <script>
      window.onload = function(e) {
        var demetraDiv = document.createElement('div');
        demetraDiv.setAttribute('id', 'demetra-app');
        demetraDiv.setAttribute('data-demetra-id', '<?=$this->demetrachat_options['id']?>');
        document.body.append(demetraDiv);
        var script = document.createElement('script');
        script.src = '<?=$APP_URL?>static/js/embed.js';
        document.getElementsByTagName('head')[0].append(script);
        var link = document.createElement('link');
        link.rel = 'stylesheet';
        link.type = 'text/css';
        link.href = '<?=$APP_URL?>static/css/embed.css';
        document.getElementsByTagName('head')[0].append(link);
      };
    </script>
    <?php
  }

}
